pub enum StreamError<E> {
TimeoutError(Elapsed),
SourceError(E),
}Expand description
Error that occurs when pulling new data from Reddit failed.
Variants
TimeoutError(Elapsed)
Returned when pulling new data timed out.
SourceError(E)
Returned when roux reported an error while pulling new data.